@@ -33,10 +33,13 @@ from typing import Dict, Iterator, Optional
 # 3rd party
 import attr
 from domdf_python_tools.stringlist import DelimitedList
-from github3 import GitHub  # type: ignore
-from github3.apps import Installation  # type: ignore
+from github3 import GitHub
+from github3.apps import Installation
 from typing_extensions import Literal
 
+# this package
+from github3_utils.headers import MACHINE_MAN
+
 __all__ = ["ContextSwitcher", "iter_installed_repos", "make_footer_links"]
 
 
@@ -121,9 +124,10 @@ def iter_installed_repos(
 			context_switcher = ContextSwitcher(client, private_key_pem, app_id)
 
 	context_switcher.login_as_app()
+	client = context_switcher.client
 
 	installation: Installation
-	for installation in client.app_installations(context_switcher.app_id):  # type: ignore
+	for installation in client.app_installations(context_switcher.app_id):
 		# print(installation)
 		# print(installation.account)
 		username = installation.account["login"]
@@ -133,10 +137,7 @@ def iter_installed_repos(
 
 		# Get repositories for this user.
 
-		headers = {
-				**installation.session.headers,
-				"Accept": "application/vnd.github.machine-man-preview+json",
-				}
+		headers = {**installation.session.headers, **MACHINE_MAN}
 
 		def get_page(page: int = 1):
 			return context_switcher.client.session.get(  # type: ignore
